@@ -1,6 +1,7 @@
 from datto.CleanText import CleanText
 from datto.Experiments import Experiments
-from datto.DataConnections import DataConnections
+from datto.DataConnections import SQLConnections
+from datto.DataConnections import S3Connections
 from datto.DataConnections import KafkaInterface
 from datto.Setup import Setup
 from datto.TrainModel import TrainModel
